//
// nono
// Copyright (C) 2020 nono project
// Licensed under nono-license.txt
//

//
// バージョンダイアログ
//

#pragma once

#include "wxnono.h"

// バージョンダイアログ
class WXVersionDlg : public wxDialog
{
	using inherited = wxDialog;
 public:
	explicit WXVersionDlg(wxWindow *parent);
	~WXVersionDlg() override;
};

// ホスト情報モニタ
class HostInfoMonitor : public Object
{
	using inherited = Object;
 public:
	HostInfoMonitor();
	~HostInfoMonitor() override;

	Monitor *monitor {};

 private:
	DECLARE_MONITOR_SCREEN(MonitorScreen);

	wxString osname {};
	wxString machinename {};
	wxString avx2str {};
	wxString neonstr {};
	wxString wxname {};
	const char *slirpver {};
};

extern HostInfoMonitor *gHostInfo;
